from .model import AiCensorPredictionInfo
from ..client import OkaeriClient, tostring, resolve_token, resolve_timeout, resolve_base_url


@tostring
class AiCensorError(BaseException):
    type: str
    message: str


class AiCensor:
    def __init__(self, token: str, timeout: int = None, base_url: str = None):
        _token = resolve_token("OKAERI_SDK_AICENSOR_TOKEN", token)
        _base_url = base_url if base_url else resolve_base_url("OKAERI_SDK_AICENSOR_BASE_PATH", "https://ai-censor.okaeri.eu")
        _timeout = timeout if timeout else resolve_timeout("OKAERI_SDK_TIMEOUT", 5000)
        self._client = OkaeriClient({'Token': _token}, _base_url, timeout)

    def is_swear(self, phrase) -> bool:
        return self.get_prediction(phrase).general.swear

    def get_prediction(self, phrase) -> AiCensorPredictionInfo:
        return self._client.post("/predict", {'phrase': phrase}, AiCensorPredictionInfo, AiCensorError)



from dataclasses import dataclass, field
from typing import List
from okaeri_sdk.client import tostring


@tostring
@dataclass
class AiCensorPredictionInfoGeneral:
    swear: bool
    breakdown: str
    domains: bool


@tostring
@dataclass
class AiCensorPredictionInfoDetails:
    basic_contains_hit: bool
    exact_match_hit: bool
    ai_label: str
    ai_probability: float
    domains_list: List[str] = field(default_factory=list)


@tostring
@dataclass
class AiCensorPredictionInfoElapsed:
    all: float
    processing: float


@tostring
@dataclass
class AiCensorPredictionInfo:
    general: AiCensorPredictionInfoGeneral
    details: AiCensorPredictionInfoDetails
    elapsed: AiCensorPredictionInfoElapsed



from setuptools import setup, find_packages

setup(
    name='okaeri-sdk',
    url='https://github.com/OkaeriPoland/okaeri-sdk-python',
    author='Dawid Sawicki',
    author_email='dawid@okaeri.eu',
    install_requires=['requests', 'marshmallow-dataclass'],
    version='1.2.3',
    license='MIT',
    description='Okaeri Services SDK',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    classifiers=[
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License",
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
)
